{% extends "admin/change_form.html" %}
{% load i18n %}
{% load admin_urls %}

{% block breadcrumbs %}
{% if skip_object_list_page %}
<div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a> &rsaquo;
    <a href="../">{{ opts.app_config.verbose_name }}</a> &rsaquo;
    {{ opts.verbose_name|capfirst }}
</div>
{% else %}
{{ block.super }}
{% endif %}
{% endblock %}

{% block object-tools-items %}
<li><a href="{% url opts|admin_urlname:'history' original.pk %}" class="historylink">{% trans "History" %}</a></li>
{% if has_absolute_url %}
<li><a href="{% url 'admin:view_on_site' content_type_id original.pk %}" class="viewsitelink">{% trans "View on site" %}</a></li>
{% endif %}
{% endblock %}
